==> haskell-reflection-2.1.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.2
id: reflection-2.1.2-Lwt0A3NRHka1hAeW9AOpLq
key: reflection-2.1.2-Lwt0A3NRHka1hAeW9AOpLq
license: BSD3
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
exposed: True
exposed-modules:
    Data.Reflection
abi: a38a07077d8484297d1aa1afa6ae8b00
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/reflection-2.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/reflection-2.1.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/reflection-2.1.2
hs-libraries: HSreflection-2.1.2-Lwt0A3NRHka1hAeW9AOpLq
depends:
    base-4.9.0.0 template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reflection-2.1.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.2
id: reflection-2.1.2-1Oix9U9tVVU4sCEhxeh8Kr
key: reflection-2.1.2-1Oix9U9tVVU4sCEhxeh8Kr
license: BSD3
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
exposed: True
exposed-modules:
    Data.Reflection
abi: 733228fc1c184e07e3013c63877b8acd
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/reflection-2.1.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/reflection-2.1.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/reflection-2.1.2
hs-libraries: HSreflection-2.1.2-1Oix9U9tVVU4sCEhxeh8Kr
depends:
    base-4.9.1.0 template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
